@@ -5,4 +5,4 @@
 #' @author Jan Lisec \email{jan.lisec@@charite.de}
 #' @references \url{http://dx.doi.org/10.1111/j.1365-313X.2011.04689.x}
 #' @keywords data
-NULL
+"met"
